summaryrefslogtreecommitdiff
path: root/sbin/dhclient/dispatch.c
diff options
context:
space:
mode:
authorKenneth R Westerback <krw@cvs.openbsd.org>2019-01-19 02:55:11 +0000
committerKenneth R Westerback <krw@cvs.openbsd.org>2019-01-19 02:55:11 +0000
commitc34b64c7246a4375d357f7aff261bbe5e665f8b2 (patch)
tree613bbd8170217398dd76ed35d1938133b5fc2e71 /sbin/dhclient/dispatch.c
parent0ee1940022ed47ed1b18b93165ee985d63932879 (diff)
IMSG_HUP -> IMSG_RESTART. sendhup() -> sendrestart.
Diffstat (limited to 'sbin/dhclient/dispatch.c')
-rw-r--r--sbin/dhclient/dispatch.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/sbin/dhclient/dispatch.c b/sbin/dhclient/dispatch.c
index bb27d9861c8..5fdeaeb7e79 100644
--- a/sbin/dhclient/dispatch.c
+++ b/sbin/dhclient/dispatch.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: dispatch.c,v 1.161 2019/01/19 02:45:05 krw Exp $ */
+/* $OpenBSD: dispatch.c,v 1.162 2019/01/19 02:55:10 krw Exp $ */
/*
* Copyright 2004 Henning Brauer <henning@openbsd.org>
@@ -76,7 +76,7 @@ void bpffd_handler(struct interface_info *);
void dhcp_packet_dispatch(struct interface_info *, struct sockaddr_in *,
struct ether_addr *);
void flush_unpriv_ibuf(void);
-void sendhup(void);
+void sendrestart(void);
/*
* Loop waiting for packets, timeouts or routing messages.
@@ -102,7 +102,7 @@ dispatch(struct interface_info *ifi, int routefd)
}
if (ifi->timeout_func != NULL)
cancel_timeout(ifi);
- sendhup();
+ sendrestart();
to_msec = 100;
} else if (ifi->timeout_func != NULL) {
time(&cur_time);
@@ -326,14 +326,14 @@ cancel_timeout(struct interface_info *ifi)
}
/*
* Inform the [priv] process a HUP was received.
*/
void
-sendhup(void)
+sendrestart(void)
{
int rslt;
- rslt = imsg_compose(unpriv_ibuf, IMSG_HUP, 0, 0, -1, NULL, 0);
+ rslt = imsg_compose(unpriv_ibuf, IMSG_RESTART, 0, 0, -1, NULL, 0);
if (rslt == -1)
- log_warn("%s: imsg_compose(IMSG_HUP)", log_procname);
+ log_warn("%s: imsg_compose(IMSG_RESTART)", log_procname);
}
@@ -326,14 +326,14 @@ cancel_timeout(struct interface_info *ifi)
}
/*
- * Inform the [priv] process a HUP was received.
+ * Inform the [priv] process it needs to restart.
*/
void